pub struct BuildCache { /* private fields */ }Expand description
Incremental build cache backed by a JSON file.
Implementations
Sourceimpl BuildCache
impl BuildCache
Sourcepub fn load(content_root: &Path) -> Result<Self, String>
pub fn load(content_root: &Path) -> Result<Self, String>
Load cache from file, or create empty if file doesn’t exist or is invalid.
Errors
Returns an error if the file exists but cannot be read.
Sourcepub fn is_unchanged(&self, path: &str, current_hash: &str) -> bool
pub fn is_unchanged(&self, path: &str, current_hash: &str) -> bool
Check if a file is unchanged since last build.
Returns true if the file hash matches the cache and all dependencies
are also unchanged.
Sourcepub fn is_unchanged_with_hashes(
&self,
path: &str,
current_hash: &str,
current_hashes: &HashMap<String, String>,
) -> bool
pub fn is_unchanged_with_hashes( &self, path: &str, current_hash: &str, current_hashes: &HashMap<String, String>, ) -> bool
Check if a file and all its dependencies are unchanged, given a map of current file hashes.
Sourcepub fn put(&mut self, path: &str, hash: String, deps: Vec<String>)
pub fn put(&mut self, path: &str, hash: String, deps: Vec<String>)
Record a file’s hash and dependencies in the cache.
Sourcepub fn prune(&mut self, existing_files: &HashSet<String>)
pub fn prune(&mut self, existing_files: &HashSet<String>)
Remove entries for files that no longer exist.