pub struct BuildResult {
pub output: CaseOutput,
pub case_pending: Vec<PendingId>,
pub registry_pending: Vec<(String, PendingId)>,
}Expand description
Result of building output: the JSON structure plus any pending write-backs.
Fields
output: CaseOutputcase_pending: Vec<PendingId>IDs generated for inline entities and relationships in case files.
registry_pending: Vec<(String, PendingId)>IDs generated for registry entities (keyed by entity name for the caller to route to the correct entity file).