pub enum SectionKind {
People,
Organizations,
Events,
Documents,
Assets,
Relationships,
Timeline,
RelatedCases,
}Expand description
The type of an H2 section, mapped from heading text.
Variants
Implementations
Sourceimpl SectionKind
impl SectionKind
Sourcepub fn is_case_section(self) -> bool
pub fn is_case_section(self) -> bool
Whether this section kind is valid in case files. People and Organizations are no longer allowed in case files.