Structs
- Pending
Id - A generated ID that needs to be written back to a source file.
Enums
- Write
Back Kind - The type of write-back insertion.
Functions
- apply_
writebacks - Apply pending ID write-backs to a file’s content.
- find_
front_ matter_ end - Find the line number of the closing
---in YAML front matter. Returns None if the file has no front matter or the closing delimiter is not found. - write_
file - Write modified content back to the file at
path.